Version history
===============

v2.0.2 (2021-12-31)

- Micro fix the admin template

v2.0 (2021-12-29)

- Add support configuration per user (by add one field to custom user model)

v1.0 (2021-10-22)

- First release
